package com.mjsoftking.dialogutilslib.init;

import android.app.Application;

import com.mjsoftking.dialogutilslib.BuildConfig;
import com.mjsoftking.dialogutilslib.callback.DialogLibActivityLifecycleCallbacks;

/**
 * 对话框工具初始化设置
 */
public class DialogLibInitSetting {

    private static final DialogLibInitSetting INSTANCE = new DialogLibInitSetting();

    public static DialogLibInitSetting getInstance() {
        return INSTANCE;
    }

    DialogLibInitSetting() {
        this.debug = BuildConfig.DEBUG;
    }

    private boolean debug;

    public boolean isDebug() {
        return debug;
    }

    /**
     * 设置debug模式，设置后强制改变模式，debug模式下控制台会打印一些日志
     * <p>
     * 默认情况下
     * 1. 使用debug版本aar时默认为true。
     * 2. 使用release版本aar时默认为false。
     */
    public DialogLibInitSetting setDebug(boolean debug) {
        this.debug = debug;
        return this;
    }

    /**
     * 注册生命周期监控，当dialog运行的activity销毁时，dialog自动结束，避免引起内存泄漏
     */
    public DialogLibInitSetting registerActivityLifecycleCallbacks(Application application) {
        application.registerActivityLifecycleCallbacks(new DialogLibActivityLifecycleCallbacks());
        return this;
    }
}
